@@ -529,7 +529,7 @@ wbWorksheet <- R6::R6Class(
 
       current <- rbindlist(xml_attr(xml = self$mergeCells, "mergeCell"))$ref
       if (length(current))
-        current_cells <- lapply(current, function(x) unname(unlist(dims_to_dataframe(x, fill = TRUE))))
+        current_cells <- lapply(current, function(x) unlist(dims_to_dataframe(x, fill = TRUE), use.names = FALSE))
 
       for (dim in dims) {
 
@@ -543,7 +543,7 @@ wbWorksheet <- R6::R6Class(
         # regmatch0 will return character(0) when x is NULL
         if (length(current)) {
 
-          new_merge     <- unname(unlist(dims_to_dataframe(sqref, fill = TRUE)))
+          new_merge     <- unlist(dims_to_dataframe(sqref, fill = TRUE), use.names = FALSE)
           intersects    <- vapply(current_cells, function(x) any(x %in% new_merge), NA)
 
           # Error if merge intersects
@@ -605,10 +605,10 @@ wbWorksheet <- R6::R6Class(
         sqref <- stringi::stri_join(sqref, collapse = ":", sep = " ")
 
         current       <- rbindlist(xml_attr(xml = self$mergeCells, "mergeCell"))$ref
-        current_cells <- lapply(current, function(x) unname(unlist(dims_to_dataframe(x, fill = TRUE))))
+        current_cells <- lapply(current, function(x) unlist(dims_to_dataframe(x, fill = TRUE)))
 
         if (!is.null(current)) {
-          new_merge     <- unname(unlist(dims_to_dataframe(sqref, fill = TRUE)))
+          new_merge     <- unlist(dims_to_dataframe(sqref, fill = TRUE), use.names = FALSE)
           intersects    <- vapply(current_cells, function(x) any(x %in% new_merge), NA)
 
           # Remove intersection
@@ -641,7 +641,7 @@ wbWorksheet <- R6::R6Class(
         rows <- rownames(ddims)
         cols <- colnames(ddims)
 
-        dims <- unname(unlist(ddims))
+        dims <- unlist(ddims, use.names = FALSE)
         sel <- cc$r %in% dims
       }
 
@@ -855,7 +855,7 @@ wbWorksheet <- R6::R6Class(
       unlockedFormula    = FALSE
     ) {
 
-      dims <- unname(unlist(dims_to_dataframe(dims, fill = TRUE)))
+      dims <- unlist(dims_to_dataframe(dims, fill = TRUE), use.names = FALSE)
 
       iEs <- self$ignoredErrors
       if (xml_node_name(iEs) == "ignoredErrors") {
